# pip install requests bs4 lxml

import json
from pathlib import Path

from bs4 import BeautifulSoup
from requests import get


def get_table(url: str) -> (str, bool):
    try:
        res = get(url=url)
        if res.status_code == 200:
            return res.text
    except Exception:
        return False


def parse_table(text: str) -> (dict, bool):
    country_alpha2 = dict()
    soup = BeautifulSoup(text, 'xml')
    countries = soup.find_all('country')
    for country in countries:
        name = country.find('name').text.strip()
        alpha2 = country.find('alpha2').text
        country_alpha2.update({alpha2: name})
    if country_alpha2:
        return country_alpha2
    return False


def main():
    if text := get_table('https://www.artlebedev.ru/country-list/xml/'):
        if country_alpha2 := parse_table(text):
            with open(Path.cwd() / 'ip2asn' / 'country_alpha2.json', 'w', encoding='utf-8') as cn:
                json.dump(country_alpha2, cn, indent=4, ensure_ascii=False)
        else:
            print("No data")
    else:
        print('No text')


if __name__ == "__main__":
    main()
